#
# spec file for package addrwatch
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           addrwatch
Version:        1.0.2
Release:        1.17
Summary:        A tool for IPv4/IPv6 and Ethernet address pairing monitoring
License:        GPL-3.0-only
URL:            https://github.com/fln/addrwatch
Source0:        https://github.com/fln/addrwatch/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf >= 2.68
BuildRequires:  automake
BuildRequires:  libevent-devel
BuildRequires:  libmysqlclient-devel
BuildRequires:  libpcap-devel
BuildRequires:  sqlite3-devel

%description
This is a tool similar to arpwatch. It main purpose is to monitor
network and log discovered Ethernet to IPv4/IPv6 address
pairings. It supports monitoring multiple network interfaces,
monitoring of VLAN tagged (802.1Q) packets, and can output to
stdout, plain text file, syslog, sqlite3 and MySQL. Addrwatch
tracks IPv6 addresses of hosts using IPv6 privacy extensions
(RFC4941).

The main difference between arpwatch and addrwatch is the format
of output files.

While arpwatch stores only current state of the pairings and
allows to send email notification when a pairing change occurs,
addrwatch do not keep persistent network pairings' state, but
instead logs all the events that allow pairing discovery.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure --enable-mysql --enable-sqlite3 --bindir=%{_sbindir}
make %{?_smp_mflags}

%install
%make_install
chmod -x scripts/dump2pcap.pl

%files
%license COPYING
%doc NEWS README.md scripts/dump2pcap.pl
%{_sbindir}/addrwatch
%{_sbindir}/addrwatch_mysql
%{_sbindir}/addrwatch_stdout
%{_sbindir}/addrwatch_syslog
%{_mandir}/man8/addrwatch.8%{?ext_man}

%changelog
* Mon Feb 24 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.2
  * Add leading / to default shared-memory name
  * Add clang-tidy support, clean most of the linter warnings
  * Remove sys_siglist usage in favor of strsignal (#12)
  * Add clang-format format support, re-style code base
  * addrwatch: Add limits header for PATH_MAX
  * Mark db_reconnect as static inline, fixes GH-11
  * Add experimental meson build support
  * Add mysql migration script, update README.md
- Drop fix-db-reconnect-issue.patch (merged upstream)
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Fri Aug  2 2019 Karol Babioch <kbabioch@suse.com>
- Using %%autosetup macro.
* Thu Aug  1 2019 Karol Babioch <kbabioch@suse.com>
- Removed subpackage due to unneeded complexity.
* Thu Aug  1 2019 Karol Babioch <kbabioch@suse.com>
- Split off addrwatch_mysql into subpackage (addrwatch-mysql).
* Thu Aug  1 2019 Karol Babioch <kbabioch@suse.com>
- Added fix-db-reconnect-issue.patch: Addresses an compilation
  issue: https://github.com/fln/addrwatch/issues/11
- Enabled MySQL support
- Applied spec-cleaner
- Removed no longer needed rpmlintrc file
* Wed May 17 2017 aloisio@gmx.com
- Update to version 1.0.1
- Dropped addrwatch-1.0-no_return_in_nonvoid.patch (merged
  upstream)
- Fixed source URL
* Thu Feb  2 2017 jengelh@inai.de
- Compact description a bit
* Fri Nov 11 2016 aloisio@gmx.com
- Added addrwatch-rpmlintrc as source
* Tue Nov  8 2016 aloisio@gmx.com
- Initial package (version 1.0)
